@@ -4,27 +4,27 @@
 #ifndef HISTORYACTION_H
 #define HISTORYACTION_H
 
-#include <kaction.h>
+#include <tdeaction.h>
 #include <kurl.h>
 #include <tqstringlist.h>
 
-class KConfig;
+class TDEConfig;
 
 
 /// defined in mainWindow.cpp
-void setActionMenuTextOnly( KAction *a, TQString const &suffix );
+void setActionMenuTextOnly( TDEAction *a, TQString const &suffix );
 
 
-class HistoryAction : KAction
+class HistoryAction : TDEAction
 {
-    HistoryAction( const TQString &text, const char *icon, const KShortcut &cut, KActionCollection *ac, const char *name );
+    HistoryAction( const TQString &text, const char *icon, const TDEShortcut &cut, TDEActionCollection *ac, const char *name );
 
     friend class HistoryCollection;
 
 public:
-    virtual void setEnabled( bool b = true ) { KAction::setEnabled( b ? !m_list.isEmpty() : false ); }
+    virtual void setEnabled( bool b = true ) { TDEAction::setEnabled( b ? !m_list.isEmpty() : false ); }
 
-    void clear() { m_list.clear(); KAction::setText( m_text ); }
+    void clear() { m_list.clear(); TDEAction::setText( m_text ); }
 
 private:
     void setText();
@@ -40,13 +40,13 @@ private:
 class HistoryCollection : public TQObject
 {
 Q_OBJECT
-  TQ_OBJECT
+  
 
 public:
-    HistoryCollection( KActionCollection *ac, TQObject *parent, const char *name );
+    HistoryCollection( TDEActionCollection *ac, TQObject *parent, const char *name );
 
-    void save( KConfig *config );
-    void restore( KConfig *config );
+    void save( TDEConfig *config );
+    void restore( TDEConfig *config );
 
 public slots:
     void push( const KURL& );
